@@ -34,7 +34,7 @@ sub _load_web_plugins {
         if $plugin !~ m/^\+/;
       $plugin =~ s/^\+//;
 
-      debug "loading Netdisco plugin $plugin";
+      $ENV{ND2_LOG_PLUGINS} && debug "loading web plugin $plugin";
       Module::Load::load $plugin;
   }
 }
@@ -71,7 +71,54 @@ Dancer::Session::Cookie::init(session);
 # workaround for https://github.com/PerlDancer/Dancer/issues/935
 hook after_error_render => sub { setting('layout' => 'main') };
 
-# this hook should be loaded _after_ all plugins
+# build list of port detail columns
+{
+  my @port_columns =
+    sort { $a->{idx} <=> $b->{idx} }
+    map  {{ name => $_, %{ setting('sidebar_defaults')->{'device_ports'}->{$_} } }}
+    grep { $_ =~ m/^c_/ } keys %{ setting('sidebar_defaults')->{'device_ports'} };
+
+  splice @port_columns, setting('device_port_col_idx_left'), 0,
+    grep {$_->{position} eq 'left'}  @{ setting('_extra_device_port_cols') };
+  splice @port_columns, setting('device_port_col_idx_mid'), 0,
+    grep {$_->{position} eq 'mid'}   @{ setting('_extra_device_port_cols') };
+  splice @port_columns, setting('device_port_col_idx_right'), 0,
+    grep {$_->{position} eq 'right'} @{ setting('_extra_device_port_cols') };
+
+  set('port_columns' => \@port_columns);
+
+  # update sidebar_defaults so hooks scanning params see new plugin cols
+  setting('sidebar_defaults')->{'device_ports'}->{ $_->{name} } = $_
+    for @port_columns;
+}
+
+hook 'before' => sub {
+  my $key = request->path;
+  if (param('tab') and ($key !~ m/ajax/)) {
+      $key .= ('/' . param('tab'));
+  }
+  $key =~ s|.*/(\w+)/(\w+)$|${1}_${2}|;
+  var(sidebar_key => $key);
+
+  # copy sidebar defaults into vars so we can mess about with it
+  foreach my $sidebar (keys %{setting('sidebar_defaults')}) {
+    vars->{'sidebar_defaults'}->{$sidebar} = { map {
+      ($_ => setting('sidebar_defaults')->{$sidebar}->{$_}->{'default'})
+    } keys %{setting('sidebar_defaults')->{$sidebar}} };
+  }
+};
+
+hook 'before_template' => sub {
+  # search or report from navbar, or reset of sidebar, can ignore params
+  return if param('firstsearch')
+    or var('sidebar_key') !~ m/^\w+_\w+$/;
+
+  # update defaults to contain the passed url params
+  # (this follows initial copy from config.yml, then cookie restore)
+  var('sidebar_defaults')->{var('sidebar_key')}->{$_} = param($_)
+    for keys %{ var('sidebar_defaults')->{var('sidebar_key')} || {} };
+};
+
 hook 'before_template' => sub {
     my $tokens = shift;
 
@@ -92,9 +139,28 @@ hook 'before_template' => sub {
     $tokens->{table_showrecordsmenu} =
       to_json( setting('table_showrecordsmenu') );
 
-    # fix Plugin Template Variables to be only path+query
-    $tokens->{$_} = $tokens->{$_}->path_query
-      for qw/search_node search_device device_ports/;
+    # linked searches will use these default url path params
+    foreach my $sidebar_key (keys %{ var('sidebar_defaults') }) {
+        my ($mode, $report) = ($sidebar_key =~ m/(\w+)_(\w+)/);
+        if ($mode =~ m/^(?:search|device)$/) {
+            $tokens->{$sidebar_key} = uri_for("/$mode", {tab => $report});
+        }
+        elsif ($mode =~ m/^report$/) {
+            $tokens->{$sidebar_key} = uri_for("/$mode/$report");
+        }
+
+        foreach my $col (keys %{ var('sidebar_defaults')->{$sidebar_key} }) {
+            $tokens->{$sidebar_key}->query_param($col,
+              var('sidebar_defaults')->{$sidebar_key}->{$col});
+        }
+
+        # fix Plugin Template Variables to be only path+query
+        $tokens->{$sidebar_key} = $tokens->{$sidebar_key}->path_query;
+    }
+
+    # helper from NetAddr::MAC for the MAC formatting
+    $tokens->{mac_format_call} = 'as_'. lc(param('mac_format'))
+      if param('mac_format');
 
     # allow very long lists of ports
     $Template::Directive::WHILE_MAX = 10_000;
